@@ -1,6 +1,6 @@
 package Bundle::Phalanx100;
 
-$Bundle::Phalanx100::VERSION = '0.06_02';
+$Bundle::Phalanx100::VERSION = '0.04';
 
 1;
 
@@ -17,53 +17,19 @@ C<perl -MCPAN -e 'install "Bundle::Phalanx100"'>
 
 =head1 CONTENTS
 
-Test::Harness
+Digest::base  - not actually part of the Phalanx 100, but required by many modules
 
-Test::Builder
+Digest::MD5 - not actually part of the Phalanx 100, but required by many modules
 
-Test::Builder::Tester
-
-Sub::Uplevel
-
-Test::Exception
-
-Test::Tester
-
-Test::NoWarnings
-
-Test::Tester
-
-Pod::Escapes
-
-Pod::Simple
-
-Test::Pod
+Compress::Zlib
 
 YAML
 
-Cwd
-
 Archive::Tar
 
 Module::Build
 
-Devel::Symdump
-
-Pod::Coverage - needed for Test::Pod::Coverage
-
-Test::Pod::Coverage
-
-Compress::Zlib
-
-IO::Zlib
-
-Archive::Zip
-
-Archive::Tar
-
-Storable
-
-Digest::MD5
+Mime::Base64
 
 URI
 
@@ -73,7 +39,9 @@ HTML::Parser
 
 LWP
 
-IPC::Run
+Term::ReadLine::Perl
+
+Test::Reporter
 
 CPANPLUS
 
@@ -81,83 +49,97 @@ DBI
 
 DBD::mysql
 
-GD
+Mail::Mailer
 
-MIME::Base64
+Bit::Vector
 
-Net::SSLeay
-
-Net::LDAP
-
-XML::Parser 
-
-Apache::ASP
-
-CGI
-
-Date::Manip
+Date::Calc
 
 DBD::Oracle
 
-DBD::Pg
+Digest::HMAC
 
 Digest::SHA1
 
-Digest::HMAC
+GD
 
-Digest::MD5
+Net::SSLeay
 
-HTML::Tagset
+IO::Socket::SSL
 
-HTML::Template
+IO::Stringy
 
-Net::Cmd
+Mail::SpamAssassin
 
-Mail::Mailer
+MIME::Lite
 
-MIME::Body
+MIME::Tools
 
 Net::DNS
 
-Time::HiRes
+Net::Telnet
 
-URI
+Parse::RecDescent
+
+Spreadsheet::WriteExcel
+
+XML::Parser
+
+AppConfig
+
+GD::Text
+
+GD::Graph
+
+Image::Info
+
+Image::Size
+
+XML::Parser::PerlSAX - libxml
+
+XML::DOM
+
+XML::XPath
+
+Template
+
+XML::Simple
 
 Apache::DBI
 
 Apache::Session
 
-Apache::Test
+Archive::Zip
 
-AppConfig
+SOAP::Lite
 
-App::Info
+XML::Writer
 
-Authen::PAM
+Bio::Perl
 
-Authen::SASL
+Error
 
-BerkeleyDB
+Cache::Cache
 
-Bit::Vector
+HTML::Template
 
-Carp::Clan
+CGI::Application
 
-Chart::Bars
+CGI::Kwiki
+
+CGI::Session
+
+List::Util
 
 Class::DBI
 
-Compress::Zlib::Perl
+Class::Date
 
 Config::IniFiles
 
 Convert::ASN1
 
-Convert::TNEF
-
-Convert::UUlib
-
-CPAN
+Crypt::Blowfish
 
 Crypt::CBC
 
@@ -165,161 +147,93 @@ Crypt::DES
 
 Crypt::SSLeay
 
-Data::Dumper
+Data::ShowTable
 
-Date::Calc
+Date::Manip
 
-DateTime
+Text::CSV_XS
 
-DBD::DB2
+DBD::CSV
 
 DBD::ODBC
 
-DBD::SQLite
+DBD::Pg
 
-DBD::Sybase
+DBIx::SearchBuilder
 
-Device::SerialPort
-
-Digest::SHA
-
-Encode
-
-Event
-
-Excel::Template
+IO::Tty
 
 Expect
 
-ExtUtils::MakeMaker
-
-File::Scan
-
-File::Spec
-
-File::Tail
-
-File::Temp
-
-GD::Graph
-
-GD::Text
-
-Getopt::Long
+Params::Validate
 
 HTML::Mason
 
-Image::Size
-
-IMAP::Admin
+HTML::Tree
 
 Inline
 
-IO
+Apache::Request
 
-IO::All
+Mac::Carbon
 
-IO::Socket::SSL
+Mac::Glue
 
-IO::String
-
-IO::Stringy
-
-XML::SAX2Perl
-
-Mail::Audit
-
-Mail::ClamAV
+Mail::Box
 
 Mail::Sendmail
 
-Math::Pari
-
 MD5
 
-MIME::Lite
-
-Module::Build
-
 MP3::Info
 
-DBD::mSQL
+Msql
 
 Net::Daemon
 
-Net::FTP::Common
-
-Net::Ping
-
-Net::Server
-
 Net::SNMP
 
 Net::SSH::Perl
 
-Net::Telnet
+PAR
 
-OLE::Storage_Lite
+PDF::API2
 
-Params::Validate
+PDL
 
-Parse::RecDescent
-
-Cwd
+Net::LDAP
 
 Image::Magick
 
-RPC::PlServer
-
-Pod::Parser
+Pod::Simple
 
 POE
 
-SNMP
+Regexp::Common
 
-SOAP::Lite
+SPOPS
 
 Spreadsheet::ParseExcel
 
-Spreadsheet::WriteExcel
-
-Spreadsheet::WriteExcelXML
-
-Storable
-
-Template
-
 Term::ReadKey
 
-Term::ReadLine::Perl
-
 Text::Iconv
 
-Date::Parse
+Text::Template
 
-Time::Timezone
+Time::ParseDate
 
-Unicode::String
-
-Unix::Syslog
-
-Verilog::Parser
+Time::Zone
 
 WWW::Mechanize
 
-XML::DOM
+XML::NamespaceSupport - not part of the "Phalanx 100" but required for XML::SAX and XML::LibXML
 
-XML::Generator
-
-XML::LibXML
-
-XML::NamespaceSupport
 
 XML::SAX
 
-XML::Simple
+XML::LibXML
 
-XML::Writer
 
 =head1 DESCRIPTION
 
